from bson.objectid import ObjectId
from stylelens_user.database_user import DataBaseUser

class Users(DataBaseUser):
  def __init__(self):
    super(Users, self).__init__()
    self.users = self.db.users
    self.images = self.db.images
    self.objects = self.db.objects

  def add_user(self, user):
    query = {}

    query['device_id'] = user['d_id']

    try:
      r = self.users.update_one(query,
                                {"$set": user},
                                upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      id = str(r.raw_result['upserted'])
      return id
    else:
      return None

  def get_user_by_id(self, id):
    query = {}
    query['_id'] = ObjectId(id)
    try:
      r = self.users.find_one(query)
    except Exception as e:
      print(e)

    return r

  def get_user_by_device_id(self, id):
    query = {}
    query['device_id'] = id
    try:
      r = self.users.find_one(query)
    except Exception as e:
      print(e)

    return r

  def add_image(self, device_id, image):
    image['device_id'] = device_id

    try:
      r = self.images.insert(image)
    except Exception as e:
      print(e)
      return None

    return str(r)


  def get_image(self, image_id):
    query = {}
    query['_id'] = ObjectId(image_id)
    try:
      r = self.images.find_one(query)
    except Exception as e:
      print(e)
      return None

    return r

  def add_object(self, device_id, object):
    object['device_id'] = device_id

    try:
      r = self.objects.insert(object)
    except Exception as e:
      print(e)
      return None

    return str(r)

  def get_object(self, object_id):
    query = {}
    query['_id'] = ObjectId(object_id)
    try:
      r = self.objects.find_one(query)
    except Exception as e:
      print(e)
      return None

    return r

  def get_objects_by_image_id(self, image_id):
    query = {}
    query['image_id'] = image_id
    try:
      r = self.objects.find(query)
    except Exception as e:
      print(e)
      return None

    return r



from bson.objectid import ObjectId
from stylelens_user.database_log import DataBaseUserLog

class UserLogs(DataBaseUserLog):
  def __init__(self):
    super(UserLogs, self).__init__()
    self.logs = self.db.logs

  def add_image_file_search_log(self, log):
    log['is_image_file_search'] = True

    if log.get('device_id', None) is None:
      print('Need a device_id')
      return None

    try:
      r = self.logs.insert(log)
    except Exception as e:
      print(e)
      return None

    if r is not None:
      return str(r)
    else:
      return None

  def add_image_index_search_log(self, log):
    log['is_image_index_search'] = True

    if log.get('device_id', None) is None:
      print('Need a device_id')
      return None

    try:
      r = self.logs.insert(log)
    except Exception as e:
      print(e)
      return None

    if r is not None:
      return str(r)
    else:
      return None

  def get_image_file_search_images(self, offset=0, limit=10):
    query = {}
    query['is_image_file_search'] = True

    projection = {}
    projection['image_id'] = 1

    try:
      r = self.logs.find(query, projection).skip(offset).limit(limit)
    except Exception as e:
      print(e)
      return None

    return list(r)

  def get_image_file_search_logs(self, offset=0, limit=10):
    query = {}
    query['is_image_file_search'] = True

    try:
      r = self.logs.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)
      return None

    return list(r)

  def get_image_file_search_logs(self, offset=0, limit=10):
    query = {}
    query['is_image_file_search'] = True

    try:
      r = self.logs.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)
      return None

    return list(r)

  def get_image_index_search_logs(self, offset=0, limit=10):
    query = {}
    query['is_image_index_search'] = True

    try:
      r = self.logs.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)
      return None

    return list(r)




# coding: utf-8

"""
    stylelens-user

    Utility package for bl-db-user, bl-db-user-log (DB)

"""


import sys
from setuptools import setup, find_packages

NAME = "stylelens-user"
VERSION = "0.0.5"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["pymongo"]

setup(
    name=NAME,
    version=VERSION,
    description="stylelens-user",
    author_email="master@bluehack.net",
    url="",
    keywords=["Swagger", "stylelens-user"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    """
)
